summaryrefslogtreecommitdiffstats
path: root/src/daemon
diff options
context:
space:
mode:
Diffstat (limited to 'src/daemon')
-rw-r--r--src/daemon/MiddleWare.cpp22
-rw-r--r--src/daemon/MiddleWare.h10
-rw-r--r--src/daemon/abrt_event.conf4
3 files changed, 20 insertions, 16 deletions
diff --git a/src/daemon/MiddleWare.h b/src/daemon/MiddleWare.h
index bf7a5807..90386c03 100644
--- a/src/daemon/MiddleWare.h
+++ b/src/daemon/MiddleWare.h
@@ -102,16 +102,6 @@ report_status_t Report(const map_crash_data_t& crash_data,
*/
mw_result_t SaveDebugDump(const char *pDebugDumpDir,
map_crash_data_t& pCrashData);
-/**
- * Get one crash info. If getting is successful,
- * then crash info is filled.
- * @param pUUID A local UUID of a crash.
- * @param pUID An UID of an user.
- * @param pCrashData A crash info.
- * @return It return results of operation. See mw_result_t.
- */
-mw_result_t FillCrashInfo(const char *crash_id,
- map_crash_data_t& pCrashData);
vector_map_crash_data_t GetCrashInfos(long caller_uid);
int CreateReportThread(const char* crash_id, long caller_uid, int force, const char* pSender);
diff --git a/src/daemon/abrt_event.conf b/src/daemon/abrt_event.conf
index 58126192..6c1ac191 100644
--- a/src/daemon/abrt_event.conf
+++ b/src/daemon/abrt_event.conf
@@ -40,6 +40,10 @@ EVENT=post-create analyzer=Kerneloops abrt-action-analyze-oops
#TODO: implement this (or add this functionality to abrt-action-install-debuginfo):
#EVENT=analyze analyzer=CCpp backtrace= trim-debuginfo-cache /var/cache/abrt-di 4096m
+# Additional directories to search for debuginfos can be specified
+# in the third argument (its format is CACHEDIR[:DEBUGINFODIR...]).
+# For example, you can specify a network-mounted shared store
+# of all debuginfos this way.
EVENT=analyze analyzer=CCpp backtrace= abrt-action-install-debuginfo "$DUMP_DIR/coredump" "/var/run/abrt/$$-$RANDOM" /var/cache/abrt-di
EVENT=analyze analyzer=CCpp backtrace= abrt-action-generate-backtrace
diff --git a/src/daemon/MiddleWare.cpp b/src/daemon/MiddleWare.cpp
index 1f849e9b..bd0e9689 100644
--- a/src/daemon/MiddleWare.cpp
+++ b/src/daemon/MiddleWare.cpp
@@ -37,16 +37,26 @@ CPluginManager* g_pPluginManager;
/**
+ * Get one crash info. If getting is successful,
+ * then crash info is filled.
+ * @param dump_dir_name A dump dir containing all necessary data.
+ * @param pCrashData A crash info.
+ * @return It return results of operation. See mw_result_t.
+ */
+static mw_result_t FillCrashInfo(const char *crash_id,
+ map_crash_data_t& pCrashData);
+
+/**
* Transforms a debugdump directory to inner crash
* report form. This form is used for later reporting.
* @param pDebugDumpDir A debugdump dir containing all necessary data.
* @param pCrashData A created crash report.
*/
-static bool DebugDumpToCrashReport(const char *pDebugDumpDir, map_crash_data_t& pCrashData)
+static bool DebugDumpToCrashReport(const char *dump_dir_name, map_crash_data_t& pCrashData)
{
- VERB3 log(" DebugDumpToCrashReport('%s')", pDebugDumpDir);
+ VERB3 log(" DebugDumpToCrashReport('%s')", dump_dir_name);
- struct dump_dir *dd = dd_opendir(pDebugDumpDir, /*flags:*/ 0);
+ struct dump_dir *dd = dd_opendir(dump_dir_name, /*flags:*/ 0);
if (!dd)
return false;
@@ -56,7 +66,7 @@ static bool DebugDumpToCrashReport(const char *pDebugDumpDir, map_crash_data_t&
if (!dd_exist(dd, *v))
{
dd_close(dd);
- log("Important file '%s/%s' is missing", pDebugDumpDir, *v);
+ log("Important file '%s/%s' is missing", dump_dir_name, *v);
return false;
}
v++;
@@ -561,7 +571,7 @@ mw_result_t SaveDebugDump(const char *dump_dir_name,
return res;
}
-mw_result_t FillCrashInfo(const char *crash_id,
+static mw_result_t FillCrashInfo(const char *crash_id,
map_crash_data_t& pCrashData)
{
CDatabase* database = g_pPluginManager->GetDatabase(g_settings_sDatabase);
@@ -37,16 +37,26 @@ CPluginManager* g_pPluginManager;
* Transforms a debugdump directory to inner crash
* report form. This form is used for later reporting.
- * @param pDebugDumpDir A debugdump dir containing all necessary data.
+ * @param dump_dir_name A debugdump dir containing all necessary data.
* @param pCrashData A created crash report.
*/